import { DVCClient as Client, DVCFeatureSet, DVCOptions, DVCVariableSet, DVCVariableValue, DVCEvent as ClientEvent, DVCUser, ErrorCallback } from './types';
import { DVCVariable } from './Variable';
import { DVCPopulatedUser } from './User';
import { EventEmitter } from './EventEmitter';
import { BucketedUserConfig } from '@devcycle/types';
import { DVCLogger } from '@devcycle/types';
export declare class DVCClient implements Client {
    private options;
    private onInitialized;
    private variableDefaultMap;
    private environmentKey;
    private userSaved;
    private _closing;
    private isConfigCached;
    logger: DVCLogger;
    config?: BucketedUserConfig;
    user: DVCPopulatedUser;
    private store;
    private eventQueue;
    private requestConsolidator;
    eventEmitter: EventEmitter;
    private streamingConnection?;
    private pageVisibilityHandler?;
    private inactivityHandlerId?;
    private windowMessageHandler?;
    constructor(environmentKey: string, user: DVCUser, options?: DVCOptions);
    onClientInitialized(): Promise<DVCClient>;
    onClientInitialized(onInitialized: ErrorCallback<DVCClient>): void;
    variable<T extends DVCVariableValue>(key: string, defaultValue: T): DVCVariable<T>;
    identifyUser(user: DVCUser): Promise<DVCVariableSet>;
    identifyUser(user: DVCUser, callback?: ErrorCallback<DVCVariableSet>): void;
    resetUser(): Promise<DVCVariableSet>;
    resetUser(callback: ErrorCallback<DVCVariableSet>): void;
    allFeatures(): DVCFeatureSet;
    allVariables(): DVCVariableSet;
    subscribe(key: string, handler: (...args: any[]) => void): void;
    unsubscribe(key: string, handler?: (...args: any[]) => void): void;
    track(event: ClientEvent): void;
    flushEvents(callback?: () => void): Promise<void>;
    close(): Promise<void>;
    get closing(): boolean;
    private refetchConfig;
    private handleConfigReceived;
    private onSSEMessage;
    private registerVisibilityChangeHandler;
    private getConfigCache;
    private initializeClient;
}
