import { DVCEvent, DVCOptions } from './types';
import { DVCPopulatedUser } from './User';
import { AxiosRequestHeaders, AxiosResponse } from 'axios';
import { BucketedUserConfig, DVCLogger } from '@devcycle/types';
export declare const HOST = ".devcycle.com";
export declare const CLIENT_SDK_URL: string;
export declare const EVENT_URL: string;
export declare const CONFIG_PATH = "/v1/sdkConfig";
export declare const EVENTS_PATH = "/v1/events";
export declare const SAVE_ENTITY_PATH = "/v1/edgedb";
export declare const baseRequestHeaders: (environmentKey?: string) => AxiosRequestHeaders;
/**
 * Base Requests
 */
export declare const get: (url: string) => Promise<AxiosResponse>;
export declare const post: (url: string, environmentKey: string, body: Record<string, unknown>) => Promise<AxiosResponse>;
export declare const patch: (url: string, environmentKey: string, body: Record<string, unknown>) => Promise<AxiosResponse>;
/**
 * Endpoints
 */
export declare const getConfigJson: (environmentKey: string, user: DVCPopulatedUser, logger: DVCLogger, options?: DVCOptions, extraParams?: {
    sse: boolean;
    lastModified?: number;
}) => Promise<BucketedUserConfig>;
export declare const publishEvents: (envKey: string | null, config: BucketedUserConfig | null, user: DVCPopulatedUser, events: DVCEvent[], logger: DVCLogger, options?: DVCOptions) => Promise<AxiosResponse>;
export declare const saveEntity: (user: DVCPopulatedUser, envKey: string, logger: DVCLogger, options?: DVCOptions) => Promise<AxiosResponse>;
declare const _default: {
    get: (url: string) => Promise<AxiosResponse<any, any>>;
    post: (url: string, environmentKey: string, body: Record<string, unknown>) => Promise<AxiosResponse<any, any>>;
    getConfigJson: (environmentKey: string, user: DVCPopulatedUser, logger: DVCLogger, options?: DVCOptions | undefined, extraParams?: {
        sse: boolean;
        lastModified?: number | undefined;
    } | undefined) => Promise<BucketedUserConfig>;
    publishEvents: (envKey: string | null, config: BucketedUserConfig | null, user: DVCPopulatedUser, events: DVCEvent[], logger: DVCLogger, options?: DVCOptions | undefined) => Promise<AxiosResponse<any, any>>;
};
export default _default;
